Python RFlink library
=====================

.. image:: https://travis-ci.org/aequitas/python-rflink.svg?branch=master
    :target: https://travis-ci.org/aequitas/python-rflink

.. image:: https://img.shields.io/pypi/v/rflink.svg
    :target: https://pypi.python.org/pypi/rflink

.. image:: https://img.shields.io/pypi/pyversions/rflink.svg
    :target: https://pypi.python.org/pypi/rflink

.. image:: https://img.shields.io/codeclimate/github/aequitas/python-rflink.svg
    :target: https://codeclimate.com/github/aequitas/python-rflink/code

.. image:: https://img.shields.io/codeclimate/coverage/github/aequitas/python-rflink.svg
    :target: https://codeclimate.com/github/aequitas/python-rflink/coverage

.. image:: https://img.shields.io/requires/github/aequitas/python-rflink.svg
    :target: https://requires.io/github/aequitas/python-rflink/requirements/

Library and CLI tools for interacting with RFlink 433MHz transceiver.

http://www.nemcon.nl/blog2/

Installation
------------

.. code-block:: bash

    $ pip install rflink
